==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/de/d59/misc__widget_8h.js <==
var misc__widget_8h =
[
    [ "AboutWidgets", "de/d59/misc__widget_8h.html#a42efb8b7980f6c97d57438d932166d6d", [
      [ "WID_A_SCROLLING_TEXT", "de/d59/misc__widget_8h.html#a42efb8b7980f6c97d57438d932166d6da70f9a823708a32e41e2d3b0683eb5498", null ],
      [ "WID_A_WEBSITE", "de/d59/misc__widget_8h.html#a42efb8b7980f6c97d57438d932166d6da017b85dbb66ab88bcfe302e04a862fe9", null ]
    ] ],
    [ "LandInfoWidgets", "de/d59/misc__widget_8h.html#a28e619b1312a20c95fb17b6a233dd9ef", [
      [ "WID_LI_BACKGROUND", "de/d59/misc__widget_8h.html#a28e619b1312a20c95fb17b6a233dd9efa69a4c51024d888f761b1cc0a5ba55930", null ]
    ] ],
    [ "QueryStringWidgets", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746", [
      [ "WID_QS_CAPTION", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746a149cc54f43a6e5acf729c06cc7f30a1a", null ],
      [ "WID_QS_TEXT", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746a2a9c6a61fda1e5ef7476219d8c86994b", null ],
      [ "WID_QS_DEFAULT", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746a140a98f779617daa77b092bf17eeeaee", null ],
      [ "WID_QS_CANCEL", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746aa3d7c88215db5bc2b91e3b764d01b42a", null ],
      [ "WID_QS_OK", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746af49e4aeb080afbc67e77efa919f1a861", null ]
    ] ],
    [ "QueryWidgets", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0", [
      [ "WID_Q_CAPTION", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0ace2c2f8ae0560f1d44145e46bae29afb", null ],
      [ "WID_Q_TEXT", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0af921c5b82fb9bc9b3af74958e45f7f0a", null ],
      [ "WID_Q_NO", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0a1fa569a65c03a361a576a9a62ba3e4aa", null ],
      [ "WID_Q_YES", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0a9f656af83666caf3b2c3e6c974988722", null ]
    ] ],
    [ "TextfileWidgets", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18c", [
      [ "WID_TF_CAPTION", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18ca9d0281a06767ad8877bac2e7b9dfe9e3", null ],
      [ "WID_TF_WRAPTEXT", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18ca5295b671ec87ab8123875fa76341df7c", null ],
      [ "WID_TF_BACKGROUND", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18ca0bb85d9dcba5e3a4b3fb108341d2c0c0", null ],
      [ "WID_TF_VSCROLLBAR", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18cac532afa7baaeef64f982f529793a06f4", null ],
      [ "WID_TF_HSCROLLBAR", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18cab95d65751ad9e86a40d9c6cf3adeba54", null ]
    ] ],
    [ "ToolTipsWidgets", "de/d59/misc__widget_8h.html#a9b6f11e7c2e75c9c00a65a60dd763739", [
      [ "WID_TT_BACKGROUND", "de/d59/misc__widget_8h.html#a9b6f11e7c2e75c9c00a65a60dd763739aebb22d9b810b9ebcb791b9d7277e4036", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/de/d59/misc__widget_8h.js <==
var misc__widget_8h =
[
    [ "AboutWidgets", "de/d59/misc__widget_8h.html#a42efb8b7980f6c97d57438d932166d6d", [
      [ "WID_A_SCROLLING_TEXT", "de/d59/misc__widget_8h.html#a42efb8b7980f6c97d57438d932166d6da70f9a823708a32e41e2d3b0683eb5498", null ],
      [ "WID_A_WEBSITE", "de/d59/misc__widget_8h.html#a42efb8b7980f6c97d57438d932166d6da017b85dbb66ab88bcfe302e04a862fe9", null ],
      [ "WID_A_COPYRIGHT", "de/d59/misc__widget_8h.html#a42efb8b7980f6c97d57438d932166d6da0dd5ff3c03a19ae6379ab0779be528be", null ]
    ] ],
    [ "LandInfoWidgets", "de/d59/misc__widget_8h.html#a28e619b1312a20c95fb17b6a233dd9ef", [
      [ "WID_LI_LOCATION", "de/d59/misc__widget_8h.html#a28e619b1312a20c95fb17b6a233dd9efa8de46a2d5eb5542c22f73f3d0f3814d9", null ],
      [ "WID_LI_BACKGROUND", "de/d59/misc__widget_8h.html#a28e619b1312a20c95fb17b6a233dd9efa69a4c51024d888f761b1cc0a5ba55930", null ]
    ] ],
    [ "QueryStringWidgets", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746", [
      [ "WID_QS_CAPTION", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746a149cc54f43a6e5acf729c06cc7f30a1a", null ],
      [ "WID_QS_TEXT", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746a2a9c6a61fda1e5ef7476219d8c86994b", null ],
      [ "WID_QS_WARNING", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746a1dde8f95e0af3d59d2f4ecc898e0029f", null ],
      [ "WID_QS_DEFAULT", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746a140a98f779617daa77b092bf17eeeaee", null ],
      [ "WID_QS_CANCEL", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746aa3d7c88215db5bc2b91e3b764d01b42a", null ],
      [ "WID_QS_OK", "de/d59/misc__widget_8h.html#a309cceed5b6b51ae147ed3978acac746af49e4aeb080afbc67e77efa919f1a861", null ]
    ] ],
    [ "QueryWidgets", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0", [
      [ "WID_Q_CAPTION", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0ace2c2f8ae0560f1d44145e46bae29afb", null ],
      [ "WID_Q_TEXT", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0af921c5b82fb9bc9b3af74958e45f7f0a", null ],
      [ "WID_Q_NO", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0a1fa569a65c03a361a576a9a62ba3e4aa", null ],
      [ "WID_Q_YES", "de/d59/misc__widget_8h.html#acddb23367b80ebcca0c8a8a808ccd7b0a9f656af83666caf3b2c3e6c974988722", null ]
    ] ],
    [ "TextfileWidgets", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18c", [
      [ "WID_TF_CAPTION", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18ca9d0281a06767ad8877bac2e7b9dfe9e3", null ],
      [ "WID_TF_WRAPTEXT", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18ca5295b671ec87ab8123875fa76341df7c", null ],
      [ "WID_TF_BACKGROUND", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18ca0bb85d9dcba5e3a4b3fb108341d2c0c0", null ],
      [ "WID_TF_VSCROLLBAR", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18cac532afa7baaeef64f982f529793a06f4", null ],
      [ "WID_TF_HSCROLLBAR", "de/d59/misc__widget_8h.html#ab5672d158261f888f006c0e80b3bf18cab95d65751ad9e86a40d9c6cf3adeba54", null ]
    ] ],
    [ "ToolTipsWidgets", "de/d59/misc__widget_8h.html#a9b6f11e7c2e75c9c00a65a60dd763739", [
      [ "WID_TT_BACKGROUND", "de/d59/misc__widget_8h.html#a9b6f11e7c2e75c9c00a65a60dd763739aebb22d9b810b9ebcb791b9d7277e4036", null ]
    ] ]
];
